@@ -2,7 +2,7 @@
 data viewer
 '''
 import pydash as _
-from .common import result
+from .common import result, getQueryParam
 import json
 import os
 
@@ -17,7 +17,7 @@ def initDataView(configAll, dbAction):
     tables = list(map(lambda x: x['name'], configAll.dbTables()))
     if disabled:
       return result('Data viewer diabled, set DATA_VIEWER_ENABLED=yes to enable it')
-    tableName = _.get(event, 'queryStringParameters.tableName') or 'bot'
+    tableName = getQueryParam(event, 'tableName') or 'bot'
     if not tableName in tables:
       return result('tableName not right', 400)
     res = dbAction(tableName, 'get')
